/* -*- Mode: C++; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
/*
 * This file is part of the libe-book project.
 *
 * This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/.
 */

#include "LRFTypes.h"

namespace libebook
{

LRFBookInfo::LRFBookInfo()
  : author()
  , title()
  , bookID()
  , publisher()
  , label()
  , categories()
  , classification()
  , freeText()
{
}

LRFDocInfo::LRFDocInfo()
  : language()
  , creator()
  , creationDate()
  , producer()
  , page(0)
{
}

LRFMetadata::LRFMetadata()
  : bookInfo()
  , docInfo()
  , keyword()
{
}

LRFColor::LRFColor()
  : r(0)
  , g(0)
  , b(0)
{
}

LRFColor::LRFColor(unsigned color)
  : r((color >> 16) & 0xff)
  , g((color >> 8) & 0xff)
  , b(color & 0xff)
{
}

LRFColor::LRFColor(const unsigned char red, const unsigned char green, const unsigned char blue)
  : r(red)
  , g(green)
  , b(blue)
{
}

LRFAttributes::LRFAttributes()
  : fontSize()
  , fontWidth()
  , fontEscapement()
  , fontOrientation()
  , fontWeight()
  , fontFacename()
  , textColor()
  , textBgColor()
  , wordSpace()
  , letterSpace()
  , baseLineSkip()
  , lineSpace()
  , parIndent()
  , parSkip()
  , height()
  , width()
  , locationX()
  , locationY()
  , italic()
  , sup()
  , sub()
{
}

}

/* vim:set shiftwidth=2 softtabstop=2 expandtab: */

